<?php

namespace Larayellow\Reviews\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Larayellow\Reviews\Repositories\Eloquent\Filters\ReviewPublicFilter;
use Larayellow\Reviews\Repositories\Eloquent\Presenters\ReviewListPresenter;
use Larayellow\Reviews\Interfaces\ReviewRepositoryInterface;

class ReviewPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(ReviewRepositoryInterface $review)
    {
        parent::__construct();
        $this->modules = $this->modules(config('larayellow.reviews.modules'), 'reviews', guard_url('reviews'));
        $this->repository = $review;

    }

    /**
     * Show review's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(ReviewPublicFilter::class)
            ->setPresenter(ReviewListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('reviews::review.names'))
            ->view('reviews::public.review.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show review.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('reviews::review.name'))
            ->view('reviews::public.review.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
