<?php

namespace Larayellow\Reviews\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Larayellow\Reviews\Models\Review;

class ReviewPolicy
{

    /**
     * Determine if the given user can view the review.
     *
     * @param UserPolicyInterface $authUser
     * @param Review $review
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Review $review)
    {
        if ($authUser->canDo('reviews.review.view') && $authUser->isAdmin()) {
            return true;
        }

        return $review->user_id == user_id() && $review->user_type == user_type();
    }

    /**
     * Determine if the given user can create a review.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('reviews.review.create');
    }

    /**
     * Determine if the given user can update the given review.
     *
     * @param UserPolicyInterface $authUser
     * @param Review $review
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Review $review)
    {
        if ($authUser->canDo('reviews.review.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $review->user_id == user_id() && $review->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given review.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Review $review)
    {
        return $review->user_id == user_id() && $review->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given review.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Review $review)
    {
        if ($authUser->canDo('reviews.review.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given review.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Review $review)
    {
        if ($authUser->canDo('reviews.review.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
