<?php

namespace Larayellow\Reviews\Providers;

use Illuminate\Support\ServiceProvider;
use Larayellow\Reviews\Reviews;

class ReviewsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'reviews');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'reviews');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Larayellow\Reviews\Providers\AuthServiceProvider::class);
        $this->app->register(\Larayellow\Reviews\Providers\RouteServiceProvider::class);
        // $this->app->register(\Larayellow\Reviews\Providers\EventServiceProvider::class);
        // $this->app->register(\Larayellow\Reviews\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('larayellow.reviews', function($app)
        {
            return $this->app->make(Reviews::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Review to repository
        $this->app->bind(
            'Larayellow\Reviews\Interfaces\ReviewRepositoryInterface',
            \Larayellow\Reviews\Repositories\Eloquent\ReviewRepository::class
        );
    }


    /**
     * Merges user's and reviews's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'larayellow.reviews'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Larayellow\Reviews\Commands\Reviews::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['larayellow.reviews'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('larayellow/reviews.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/reviews')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/reviews')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
